from typing import List
from os.path import join
from os.path import dirname
from re import compile as Compile
from itertools import product

def load_words(file_name: str) -> List[str]:
    """
    this function is used to load words from .txt file.
    """
    with open(join(dirname(__file__), 'words', f'{file_name}.txt'), 'r', encoding='utf8') as file:
        return list(file.read().strip())

ji_pattern = Compile('|'.join(load_words('ji')))
zhiyin_pattern = Compile('|'.join(x + y for x, y in product(load_words('zhi'), load_words('yin'))))



"""
this is the setup of this package.
"""

from setuptools import setup
from setuptools import find_packages

from just_because import VERSION

with open('just_because/requirements.txt', 'r', encoding='utf8') as file:
    install_requires = list(map(lambda x: x.strip(), file.readlines()))

with open('README.md', 'r', encoding='utf8') as file:
    long_description = file.read()

setup(
    name='just-because',
    version='.'.join(map(str, VERSION)),
    author='ikun',
    author_email='zqmillet@qq.com',
    url='https://github.com/zqmillet/just-because',
    description='鸡你太美',
    packages=find_packages(),
    install_requires=install_requires,
    long_description=long_description,
    long_description_content_type='text/markdown',
    package_data={
        'just_because': ['words/*.txt'],
    },
)
